@@ -2,7 +2,7 @@
 """DB-SIG compliant module for communicating with MS SQL servers"""
 
 __author__ = 'Mikhail Denisenko <denisenkom@gmail.com>'
-__version__ = '1.0.2'
+__version__ = '1.0.3'
 
 import logging
 import decimal
@@ -89,6 +89,10 @@ class _Connection(object):
         self._assert_open()
         return self._conn.product_version
 
+    @property
+    def mars_enabled(self):
+        return self._conn.mars_enabled
+
     def __init__(self, login, as_dict, autocommit):
         self._login = login
         self._as_dict = as_dict
@@ -348,7 +352,8 @@ class _Connection(object):
                     rc, result_type, _ = tds_process_tokens(session, TDS_TOKEN_TRAILING)
                     if rc != TDS_NO_MORE_RESULTS:
                         raise InterfaceError('Results are still pending on connection')
-                cursor._session = session
+                if cursor is not None:
+                    cursor._session = session
             self._active_cursor = cursor
 
     def _execute(self, cursor, operation, params):
@@ -610,7 +615,7 @@ def connect(server='.', database='', user='', password='', timeout=0,
         login_timeout=60, as_dict=False,
         host='', appname=None, port=None, tds_version=TDS74,
         encryption_level=TDS_ENCRYPTION_OFF, autocommit=True,
-        blocksize=4096, use_mars=True, auth=None, readonly=False):
+        blocksize=4096, use_mars=False, auth=None, readonly=False):
     """
     Constructor for creating a connection to the database. Returns a
     Connection object.
